@@ -4,6 +4,7 @@ Author: Jalil Nourisa
 import time
 import numpy as np
 import os
+from pprogress import ProgressBar
 import json
 from diversipy import lhd_matrix
 from diversipy import transform_spread_out
@@ -157,10 +158,14 @@ class ABC:
         paramsets = self.comm.bcast(paramsets,root = 0) 
 
         def run_model(start,end):
+            pb = ProgressBar(end-start)
             distances = []
             for i in range(start,end):
                 distance = self.settings["run_func"](paramsets[i],self.settings["args"])
                 distances.append(distance)
+
+                pb.update()
+            pb.done()
             return distances
         distances_perCore = run_model(portion[0],portion[1])
         
